@@ -24,34 +24,6 @@ class BaseCommand(Console, ProgressBar, IBaseCommand):
 
     The class integrates with the framework's console and progress bar systems,
     allowing commands to provide rich user feedback during execution.
-
-    Attributes
-    ----------
-    timestamps : bool, default True
-        Controls whether timestamps are included in console output messages.
-        When True, all console output will be prefixed with timestamp information.
-    signature : str
-        Defines the command signature string used for command registration and
-        automatic help text generation. This should follow the framework's
-        signature format conventions.
-    description : str
-        Human-readable description of the command's purpose and functionality.
-        Used in help documentation and command listing interfaces.
-    _args : Dict[str, Any], default {}
-        Dictionary containing parsed command-line arguments and options.
-        Populated automatically by the command parser before handle() execution.
-    arguments : List[CLIArgument], default []
-        List of CLIArgument instances defining the command's accepted arguments
-        and options. Used for argument parsing and validation.
-
-    Methods
-    -------
-    handle()
-        Abstract method that must be implemented by subclasses to define the
-        main command execution logic.
-    argument(key: str)
-        Safely retrieves argument values from the parsed arguments dictionary
-        with type validation and error handling.
     """
 
     # Enable timestamps in console output by default
@@ -64,12 +36,43 @@ class BaseCommand(Console, ProgressBar, IBaseCommand):
     description: str
 
     # Dictionary to store parsed command-line arguments and options
-    _args: Dict[str, Any] = {}
+    __args: Dict[str, Any] = {}
 
-    # List of CLIArgument instances defining command arguments
-    arguments: List[CLIArgument] = []
+    async def options(self) -> List[CLIArgument]:
+        """
+        Defines the command-line arguments and options accepted by the command.
 
-    def handle(self):
+        This asynchronous method should be overridden by subclasses to specify the list of
+        command-line arguments and options that the command supports. Each argument or option
+        should be represented as a CLIArgument object, which encapsulates details such as the
+        argument's name, type, default value, and help description.
+
+        This method enables the framework to automatically parse, validate, and document
+        the available arguments for each command, ensuring consistent user experience
+        across all commands.
+
+        Parameters
+        ----------
+        None
+
+        Returns
+        -------
+        List
+            A list of CLIArgument objects, where each object describes a single
+            command-line argument or option accepted by the command. If the command
+            does not accept any arguments or options, an empty list is returned.
+
+        Notes
+        -----
+        Subclasses should override this method to declare their specific arguments.
+        The returned list is used by the framework for argument parsing and help
+        text generation.
+        """
+
+        # Return an empty list by default; subclasses should override to provide arguments
+        return []
+
+    async def handle(self):
         """
         Execute the main command logic.
 
@@ -99,6 +102,70 @@ class BaseCommand(Console, ProgressBar, IBaseCommand):
         # Raise an error to enforce implementation in subclasses
         raise NotImplementedError("The 'handle' method must be implemented in the subclass.")
 
+    def setArguments(self, args: Dict[str, Any]) -> None:
+        """
+        Populate the internal arguments dictionary with parsed command-line arguments and options.
+
+        This method is intended for internal use by the command parsing mechanism to initialize
+        the internal arguments state before command execution. It assigns the provided dictionary
+        of arguments and options to the internal storage, making them accessible via the
+        `argument()` and `arguments()` methods.
+
+        Parameters
+        ----------
+        args : Dict[str, Any]
+            Dictionary containing parsed command-line arguments and options, where each key
+            represents an argument name and each value is the corresponding argument value.
+
+        Returns
+        -------
+        None
+            This method does not return any value. It updates the internal state of the command
+            instance to reflect the provided arguments.
+
+        Raises
+        ------
+        ValueError
+            If the provided `args` parameter is not a dictionary.
+
+        Notes
+        -----
+        This method is automatically invoked by the command framework prior to the execution
+        of the `handle()` method. It should not be called directly by command implementations.
+        """
+
+        # Ensure the provided arguments are in dictionary form
+        if not isinstance(args, dict):
+            raise ValueError(f"Arguments must be a dictionary, got '{type(args).__name__}' instead.")
+
+        # Store the parsed arguments internally for later retrieval
+        self.__args = args
+
+    def arguments(self) -> Dict[str, Any]:
+        """
+        Retrieve the entire dictionary of parsed command-line arguments and options.
+
+        This method provides access to all arguments and options that have been parsed
+        and stored internally for the current command execution. It is useful for
+        scenarios where bulk access to all argument values is required, such as
+        dynamic processing or debugging.
+
+        Returns
+        -------
+        Dict[str, Any]
+            A dictionary containing all parsed command-line arguments and options,
+            where each key is the argument name and each value is the corresponding
+            argument value.
+
+        Notes
+        -----
+        The returned dictionary reflects the current state of the command's arguments.
+        Modifying the returned dictionary will affect the internal state of the command.
+        """
+
+        # Return the internal dictionary containing all parsed arguments and options
+        return self.__args
+
     def argument(self, key: str, default: Any = None) -> Any:
         """
         Retrieve the value of a specific command-line argument by key with optional default fallback.
@@ -131,7 +198,7 @@ class BaseCommand(Console, ProgressBar, IBaseCommand):
         ValueError
             If the provided key parameter is not of string type.
         ValueError
-            If the internal _args attribute is not of dictionary type, indicating
+            If the internal __args attribute is not of dictionary type, indicating
             a corrupted or improperly initialized command state.
         """
 
@@ -140,8 +207,8 @@ class BaseCommand(Console, ProgressBar, IBaseCommand):
             raise ValueError(f"Argument key must be a string, got '{type(key).__name__}' instead.")
 
         # Ensure the internal args attribute is a valid dictionary
-        if not isinstance(self._args, dict):
-            raise ValueError(f"Arguments must be a dictionary, got '{type(self._args).__name__}' instead.")
+        if not isinstance(self.__args, dict):
+            raise ValueError(f"Arguments must be a dictionary, got '{type(self.__args).__name__}' instead.")
 
         # Safely retrieve the argument value with optional default fallback
-        return self._args.get(key, default)
\ No newline at end of file
+        return self.__args.get(key, default)
\ No newline at end of file
